@@ -109,6 +109,7 @@ typedef struct
   GtkWidget *video_vbox;
 
   GtkWidget *effect_frame;
+  GtkWidget *effect_alignment;
   GtkWidget *effect_chooser;
   GtkWidget *throbber_frame;
   GtkWidget *throbber;
@@ -190,10 +191,11 @@ cheese_about_dialog_handle_url (GtkAboutDialog *dialog, const char *url, gpointe
 {
   GError    *error = NULL;
   GtkWidget *error_dialog;
-  gboolean   ret;
+  GdkScreen *screen;
 
-  ret = g_app_info_launch_default_for_uri (url, NULL, &error);
-  if (ret == FALSE)
+  screen = gtk_widget_get_screen (GTK_WIDGET (dialog));
+  gtk_show_uri (screen, url, gtk_get_current_event_time (), &error);
+  if (error != NULL)
   {
     error_dialog = gtk_message_dialog_new (GTK_WINDOW (dialog),
                                            GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -212,12 +214,13 @@ cheese_about_dialog_handle_email (GtkAboutDialog *dialog, const char *email, gpo
   char      *uri;
   GError    *error = NULL;
   GtkWidget *error_dialog;
-  gboolean   ret;
+  GdkScreen *screen;
 
   uri = g_strconcat ("mailto:", email, NULL);
 
-  ret = g_app_info_launch_default_for_uri (uri, NULL, &error);
-  if (ret == FALSE)
+  screen = gtk_widget_get_screen (GTK_WIDGET (dialog));
+  gtk_show_uri (screen, uri, gtk_get_current_event_time (), &error);
+  if (error != NULL)
   {
     error_dialog = gtk_message_dialog_new (GTK_WINDOW (dialog),
                                            GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -283,12 +286,8 @@ cheese_window_fullscreen_set_timeout (CheeseWindow *cheese_window)
   GSource *source;
 
   cheese_window_fullscreen_clear_timeout (cheese_window);
-
-  /* make a difference between effects page and video preview */
-  if (gtk_notebook_get_current_page (GTK_NOTEBOOK (cheese_window->notebook)) == 0)
-    source = g_timeout_source_new (FULLSCREEN_TIMEOUT);
-  else
-    source = g_timeout_source_new (FULLSCREEN_EFFECTS_TIMEOUT);
+  
+  source = g_timeout_source_new (FULLSCREEN_TIMEOUT);
 
   g_source_set_callback (source, cheese_window_fullscreen_timeout_cb, cheese_window, NULL);
   g_source_attach (source, NULL);
@@ -321,8 +320,10 @@ cheese_window_fullscreen_motion_notify_cb (GtkWidget      *widget,
     {
       cheese_window_fullscreen_show_bar (cheese_window);
     }
-
-    cheese_window_fullscreen_set_timeout (cheese_window);
+    
+    //don't set the timeout in effect-chooser mode
+    if (gtk_notebook_get_current_page (GTK_NOTEBOOK (cheese_window->notebook)) != 1)
+      cheese_window_fullscreen_set_timeout (cheese_window);
   }
   return FALSE;
 }
@@ -354,9 +355,13 @@ cheese_window_toggle_fullscreen (GtkWidget *widget, CheeseWindow *cheese_window)
                       cheese_window);
 
     gtk_window_fullscreen (GTK_WINDOW (cheese_window->window));
-
+    
+    gtk_widget_set_size_request (cheese_window->effect_alignment, -1, FULLSCREEN_POPUP_HEIGHT);
     cheese_window_fullscreen_show_bar (cheese_window);
-    cheese_window_fullscreen_set_timeout (cheese_window);
+    
+    //don't set the timeout in effect-chooser mode
+    if (gtk_notebook_get_current_page (GTK_NOTEBOOK (cheese_window->notebook)) != 1)
+      cheese_window_fullscreen_set_timeout (cheese_window);
 
     cheese_window->isFullscreen = TRUE;
   }
@@ -365,13 +370,14 @@ cheese_window_toggle_fullscreen (GtkWidget *widget, CheeseWindow *cheese_window)
     gtk_widget_show_all (cheese_window->window);
     gtk_widget_hide_all (cheese_window->fullscreen_popup);
     gtk_widget_modify_bg (cheese_window->window, GTK_STATE_NORMAL, NULL);
-
+    
     g_signal_handlers_disconnect_by_func (cheese_window->window,
                                           (gpointer) cheese_window_fullscreen_motion_notify_cb, cheese_window);
     g_signal_handlers_disconnect_by_func (cheese_window->screen,
                                           (gpointer) cheese_window_fullscreen_motion_notify_cb, cheese_window);
 
     gtk_window_unfullscreen (GTK_WINDOW (cheese_window->window));
+    gtk_widget_set_size_request (cheese_window->effect_alignment, -1, -1);
     cheese_window->isFullscreen = FALSE;
 
     cheese_window_fullscreen_clear_timeout (cheese_window);
@@ -447,17 +453,19 @@ cheese_window_cmd_open (GtkWidget *widget, CheeseWindow *cheese_window)
 {
   char      *uri;
   char      *filename;
-  gboolean   ret;
   GError    *error = NULL;
   GtkWidget *dialog;
+  GdkScreen *screen;
 
   filename = cheese_thumb_view_get_selected_image (CHEESE_THUMB_VIEW (cheese_window->thumb_view));
   g_return_if_fail (filename);
   uri = g_filename_to_uri (filename, NULL, NULL);
   g_free (filename);
 
-  ret = g_app_info_launch_default_for_uri (uri, NULL, &error);
-  if (ret == FALSE)
+  screen = gtk_widget_get_screen (GTK_WIDGET (cheese_window->window));
+  gtk_show_uri (screen, uri, gtk_get_current_event_time (), &error);
+
+  if (error != NULL)
   {
     dialog = gtk_message_dialog_new (GTK_WINDOW (cheese_window->window),
                                      GTK_DIALOG_DESTROY_WITH_PARENT,
@@ -862,7 +870,7 @@ cheese_window_cmd_command_line (GtkAction *action, CheeseWindow *cheese_window)
   if (strcmp (action_name, "SendByMail") == 0)
   {
     char *path;
-    command_line = g_strdup_printf ("gnome-open mailto:?subject='%s'", _("Media files"));
+    command_line = g_strdup_printf ("xdg-open mailto:?subject='%s'", _("Media files"));
     for (l = files; l != NULL; l = l->next)
     {
       path         = g_file_get_path (l->data);
@@ -925,11 +933,12 @@ static void
 cheese_window_cmd_help_contents (GtkAction *action, CheeseWindow *cheese_window)
 {
   GError  *error = NULL;
-  gboolean ret;
+  GdkScreen *screen;
 
-  ret = g_app_info_launch_default_for_uri ("ghelp:cheese", NULL, &error);
+  screen = gtk_widget_get_screen (GTK_WIDGET (cheese_window));
+  gtk_show_uri (screen, "ghelp:cheese", gtk_get_current_event_time (), &error);
 
-  if (ret == FALSE)
+  if (error != NULL)
   {
     GtkWidget *d;
     d = gtk_message_dialog_new (GTK_WINDOW (cheese_window->window),
@@ -1014,7 +1023,7 @@ cheese_window_cmd_about (GtkAction *action, CheeseWindow *cheese_window)
                          "translator-credits", translators,
                          "artists", artists,
                          "documenters", documenters,
-                         "website", "http://www.gnome.org/projects/cheese",
+                         "website", "http://projects.gnome.org/cheese",
                          "website-label", _("Cheese Website"),
                          "logo-icon-name", "cheese",
                          "wrap-license", TRUE,
@@ -1571,6 +1580,7 @@ cheese_window_create_window (CheeseWindow *cheese_window)
   cheese_window->throbber_frame              = GTK_WIDGET (gtk_builder_get_object (builder, "throbber_frame"));
   cheese_window->countdown_frame             = GTK_WIDGET (gtk_builder_get_object (builder, "countdown_frame"));
   cheese_window->effect_frame                = GTK_WIDGET (gtk_builder_get_object (builder, "effect_frame"));
+  cheese_window->effect_alignment            = GTK_WIDGET (gtk_builder_get_object (builder, "effect_alignment"));
   cheese_window->message_area_frame          = GTK_WIDGET (gtk_builder_get_object (builder, "message_area_frame"));
   cheese_window->fullscreen_popup            = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_popup"));
   cheese_window->fullscreen_bar              = GTK_WIDGET (gtk_builder_get_object (builder, "fullscreen_notebook_bar"));
@@ -1725,7 +1735,7 @@ cheese_window_create_window (CheeseWindow *cheese_window)
   }
   else
   {
-    path = g_find_program_in_path ("gnome-open");
+    path = g_find_program_in_path ("xdg-open");
     gtk_action_group_set_visible (cheese_window->actions_mail, path != NULL);
     gtk_action_group_set_visible (cheese_window->actions_sendto, FALSE);
   }
@@ -1869,7 +1879,7 @@ setup_camera (CheeseWindow *cheese_window)
                                      GTK_BUTTONS_OK,
                                      "%s", primary);
     gtk_message_dialog_format_secondary_markup (GTK_MESSAGE_DIALOG (dialog),
-                                                secondary);
+                                                "%s", secondary);
     gtk_dialog_run (GTK_DIALOG (dialog));
     gtk_widget_destroy (dialog);
     g_error_free (error);
